# Copyright 2017 Google Inc.
#
# Licensed under the Apache License, Version 2.0 (the &quot;License&quot;);
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an &quot;AS IS&quot; BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# NOTE: This class is auto generated by the swagger code generator program.
# https://github.com/swagger-api/swagger-codegen.git
# Do not edit the class manually.

defmodule GoogleApi.ReplicaPool.V1beta2.Api.ZoneOperations do
  @moduledoc """
  API calls for all endpoints tagged `ZoneOperations`.
  """

  alias GoogleApi.ReplicaPool.V1beta2.Connection
  import GoogleApi.ReplicaPool.V1beta2.RequestBuilder

  @doc """
  Retrieves the specified zone-specific operation resource.

  ## Parameters

  - connection (GoogleApi.ReplicaPool.V1beta2.Connection): Connection to server
  - project (String): Name of the project scoping this request.
  - zone (String): Name of the zone scoping this request.
  - operation (String): Name of the operation resource to return.
  - opts (KeywordList): [optional] Optional parameters
    - :alt (String): Data format for the response.
    - :fields (String): Selector specifying which fields to include in a partial response.
    - :key (String): API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
    - :oauth_token (String): OAuth 2.0 token for the current user.
    - :pretty_print (Boolean): Returns response with indentations and line breaks.
    - :quota_user (String): Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters. Overrides userIp if both are provided.
    - :user_ip (String): IP address of the site where the request originates. Use this if you want to enforce per-user limits.

  ## Returns

  {:ok, %GoogleApi.ReplicaPool.V1beta2.Model.Operation{}} on success
  {:error, info} on failure
  """
  @spec replicapool_zone_operations_get(
          Tesla.Env.client(),
          String.t(),
          String.t(),
          String.t(),
          keyword()
        ) :: {:ok, GoogleApi.ReplicaPool.V1beta2.Model.Operation.t()} | {:error, Tesla.Env.t()}
  def replicapool_zone_operations_get(connection, project, zone, operation, opts \\ []) do
    optional_params = %{
      :alt => :query,
      :fields => :query,
      :key => :query,
      :oauth_token => :query,
      :prettyPrint => :query,
      :quotaUser => :query,
      :userIp => :query
    }

    %{}
    |> method(:get)
    |> url("/{project}/zones/{zone}/operations/{operation}", %{
      "project" => URI.encode_www_form(project),
      "zone" => URI.encode_www_form(zone),
      "operation" => URI.encode_www_form(operation)
    })
    |> add_optional_params(optional_params, opts)
    |> Enum.into([])
    |> (&Connection.request(connection, &1)).()
    |> decode(%GoogleApi.ReplicaPool.V1beta2.Model.Operation{})
  end

  @doc """
  Retrieves the list of operation resources contained within the specified zone.

  ## Parameters

  - connection (GoogleApi.ReplicaPool.V1beta2.Connection): Connection to server
  - project (String): Name of the project scoping this request.
  - zone (String): Name of the zone scoping this request.
  - opts (KeywordList): [optional] Optional parameters
    - :alt (String): Data format for the response.
    - :fields (String): Selector specifying which fields to include in a partial response.
    - :key (String): API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
    - :oauth_token (String): OAuth 2.0 token for the current user.
    - :pretty_print (Boolean): Returns response with indentations and line breaks.
    - :quota_user (String): Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters. Overrides userIp if both are provided.
    - :user_ip (String): IP address of the site where the request originates. Use this if you want to enforce per-user limits.
    - :filter (String): Optional. Filter expression for filtering listed resources.
    - :max_results (Integer): Optional. Maximum count of results to be returned. Maximum value is 500 and default value is 500.
    - :page_token (String): Optional. Tag returned by a previous list request truncated by maxResults. Used to continue a previous list request.

  ## Returns

  {:ok, %GoogleApi.ReplicaPool.V1beta2.Model.OperationList{}} on success
  {:error, info} on failure
  """
  @spec replicapool_zone_operations_list(Tesla.Env.client(), String.t(), String.t(), keyword()) ::
          {:ok, GoogleApi.ReplicaPool.V1beta2.Model.OperationList.t()} | {:error, Tesla.Env.t()}
  def replicapool_zone_operations_list(connection, project, zone, opts \\ []) do
    optional_params = %{
      :alt => :query,
      :fields => :query,
      :key => :query,
      :oauth_token => :query,
      :prettyPrint => :query,
      :quotaUser => :query,
      :userIp => :query,
      :filter => :query,
      :maxResults => :query,
      :pageToken => :query
    }

    %{}
    |> method(:get)
    |> url("/{project}/zones/{zone}/operations", %{
      "project" => URI.encode_www_form(project),
      "zone" => URI.encode_www_form(zone)
    })
    |> add_optional_params(optional_params, opts)
    |> Enum.into([])
    |> (&Connection.request(connection, &1)).()
    |> decode(%GoogleApi.ReplicaPool.V1beta2.Model.OperationList{})
  end
end
